@@ -30,6 +30,7 @@ from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
 
+from openstackclient.common import progressbar
 from openstackclient.common import sdk_utils
 from openstackclient.i18n import _
 from openstackclient.identity import common
@@ -255,6 +256,12 @@ class CreateImage(command.ShowOne):
             help=_("Force image creation if volume is in use "
                    "(only meaningful with --volume)"),
         )
+        parser.add_argument(
+            "--progress",
+            action="store_true",
+            default=False,
+            help=_("Show upload progress bar."),
+        )
         parser.add_argument(
             '--sign-key-path',
             metavar="<sign-key-path>",
@@ -324,6 +331,14 @@ class CreateImage(command.ShowOne):
             metavar="<project>",
             help=_("Set an alternate project on this image (name or ID)"),
         )
+        parser.add_argument(
+            "--import",
+            dest="use_import",
+            action="store_true",
+            help=_(
+                "Force the use of glance image import instead of"
+                " direct upload")
+        )
         common.add_project_domain_option_to_parser(parser)
         for deadopt in self.deadopts:
             parser.add_argument(
@@ -346,7 +361,7 @@ class CreateImage(command.ShowOne):
 
         # Build an attribute dict from the parsed args, only include
         # attributes that were actually set on the command line
-        kwargs = {}
+        kwargs = {'allow_duplicates': True}
         copy_attrs = ('name', 'id',
                       'container_format', 'disk_format',
                       'min_disk', 'min_ram', 'tags', 'visibility')
@@ -388,6 +403,9 @@ class CreateImage(command.ShowOne):
                 parsed_args.project_domain,
             ).id
 
+        if parsed_args.use_import:
+            kwargs['use_import'] = True
+
         # open the file first to ensure any failures are handled before the
         # image is created. Get the file name (if it is file, and not stdin)
         # for easier further handling.
@@ -401,6 +419,11 @@ class CreateImage(command.ShowOne):
         if fp is None and parsed_args.file:
             LOG.warning(_("Failed to get an image file."))
             return {}, {}
+        if fp is not None and parsed_args.progress:
+            filesize = os.path.getsize(fname)
+            if filesize is not None:
+                kwargs['validate_checksum'] = False
+                kwargs['data'] = progressbar.VerboseFileWrapper(fp, filesize)
         elif fname:
             kwargs['filename'] = fname
         elif fp:
@@ -429,8 +452,14 @@ class CreateImage(command.ShowOne):
                         prompt=("Please enter private key password, leave "
                                 "empty if none: "),
                         confirm=False)
+
                     if not pw or len(pw) < 1:
                         pw = None
+                    else:
+                        # load_private_key() requires the password to be
+                        # passed as bytes
+                        pw = pw.encode()
+
                     signer.load_private_key(
                         sign_key_path,
                         password=pw)
@@ -574,6 +603,12 @@ class ListImage(command.Lister):
                     "The supported options are: %s. ") %
                   ', '.join(MEMBER_STATUS_CHOICES))
         )
+        parser.add_argument(
+            '--project',
+            metavar='<project>',
+            help=_("Search by project (admin only) (name or ID)")
+        )
+        common.add_project_domain_option_to_parser(parser)
         parser.add_argument(
             '--tag',
             metavar='<tag>',
@@ -619,6 +654,7 @@ class ListImage(command.Lister):
         return parser
 
     def take_action(self, parsed_args):
+        identity_client = self.app.client_manager.identity
         image_client = self.app.client_manager.image
 
         kwargs = {}
@@ -642,6 +678,14 @@ class ListImage(command.Lister):
             kwargs['member_status'] = parsed_args.member_status
         if parsed_args.tag:
             kwargs['tag'] = parsed_args.tag
+        project_id = None
+        if parsed_args.project:
+            project_id = common.find_project(
+                identity_client,
+                parsed_args.project,
+                parsed_args.project_domain,
+            ).id
+            kwargs['owner'] = project_id
         if parsed_args.long:
             columns = (
                 'ID',
@@ -786,7 +830,11 @@ class SaveImage(command.Command):
         image_client = self.app.client_manager.image
         image = image_client.find_image(parsed_args.image)
 
-        image_client.download_image(image.id, output=parsed_args.file)
+        output_file = parsed_args.file
+        if output_file is None:
+            output_file = getattr(sys.stdout, "buffer", sys.stdout)
+
+        image_client.download_image(image.id, stream=True, output=output_file)
 
 
 class SetImage(command.Command):
@@ -1145,7 +1193,7 @@ class UnsetImage(command.Command):
         if parsed_args.properties:
             for k in parsed_args.properties:
                 if k in image:
-                    kwargs[k] = None
+                    delattr(image, k)
                 elif k in image.properties:
                     # Since image is an "evil" object from SDK POV we need to
                     # pass modified properties object, so that SDK can figure
