@@ -158,6 +158,19 @@ def _get_attrs(client_manager, parsed_args):
             parsed_args.disable_uplink_status_propagation):
         attrs['propagate_uplink_status'] = False
 
+    if ('numa_policy_required' in parsed_args and
+            parsed_args.numa_policy_required):
+        attrs['numa_affinity_policy'] = 'required'
+    elif ('numa_policy_preferred' in parsed_args and
+          parsed_args.numa_policy_preferred):
+        attrs['numa_affinity_policy'] = 'preferred'
+    elif ('numa_policy_legacy' in parsed_args and
+          parsed_args.numa_policy_legacy):
+        attrs['numa_affinity_policy'] = 'legacy'
+
+    if 'device_profile' in parsed_args and parsed_args.device_profile:
+        attrs['device_profile'] = parsed_args.device_profile
+
     return attrs
 
 
@@ -265,6 +278,22 @@ def _add_updatable_args(parser):
         help=_("Set DNS name for this port "
                "(requires DNS integration extension)")
     )
+    numa_affinity_policy_group = parser.add_mutually_exclusive_group()
+    numa_affinity_policy_group.add_argument(
+        '--numa-policy-required',
+        action='store_true',
+        help=_("NUMA affinity policy required to schedule this port")
+    )
+    numa_affinity_policy_group.add_argument(
+        '--numa-policy-preferred',
+        action='store_true',
+        help=_("NUMA affinity policy preferred to schedule this port")
+    )
+    numa_affinity_policy_group.add_argument(
+        '--numa-policy-legacy',
+        action='store_true',
+        help=_("NUMA affinity policy using legacy mode to schedule this port")
+    )
 
 
 # TODO(abhiraut): Use the SDK resource mapped attribute names once the
@@ -417,6 +446,11 @@ class CreatePort(command.ShowOne):
                    "ip-address=<ip-address>[,mac-address=<mac-address>] "
                    "(repeat option to set multiple allowed-address pairs)")
         )
+        parser.add_argument(
+            '--device-profile',
+            metavar='<device-profile>',
+            help=_('Cyborg port device profile')
+        )
         _tag.add_tag_option_to_parser_for_create(parser, _('port'))
         return parser
 
@@ -454,12 +488,23 @@ class CreatePort(command.ShowOne):
         if parsed_args.qos_policy:
             attrs['qos_policy_id'] = client.find_qos_policy(
                 parsed_args.qos_policy, ignore_missing=False).id
+
+        set_tags_in_post = bool(
+            client.find_extension('tag-ports-during-bulk-creation'))
+        if set_tags_in_post:
+            if parsed_args.no_tag:
+                attrs['tags'] = []
+            if parsed_args.tags:
+                attrs['tags'] = list(set(parsed_args.tags))
+
         with common.check_missing_extension_if_error(
                 self.app.client_manager.network, attrs):
             obj = client.create_port(**attrs)
 
-        # tags cannot be set when created, so tags need to be set later.
-        _tag.update_tags_for_set(client, obj, parsed_args)
+        if not set_tags_in_post:
+            # tags cannot be set when created, so tags need to be set later.
+            _tag.update_tags_for_set(client, obj, parsed_args)
+
         display_columns, columns = _get_columns(obj)
         data = utils.get_item_properties(obj, columns, formatters=_formatters)
 
@@ -555,6 +600,11 @@ class ListPort(command.Lister):
             metavar='<project>',
             help=_("List ports according to their project (name or ID)")
         )
+        parser.add_argument(
+            '--name',
+            metavar='<name>',
+            help=_("List ports according to their name")
+        )
         identity_common.add_project_domain_option_to_parser(parser)
         parser.add_argument(
             '--fixed-ip',
@@ -622,13 +672,15 @@ class ListPort(command.Lister):
             ).id
             filters['tenant_id'] = project_id
             filters['project_id'] = project_id
+        if parsed_args.name:
+            filters['name'] = parsed_args.name
         if parsed_args.fixed_ip:
             filters['fixed_ips'] = _prepare_filter_fixed_ips(
                 self.app.client_manager, parsed_args)
 
         _tag.get_tag_filtering_args(parsed_args, filters)
 
-        data = network_client.ports(**filters)
+        data = network_client.ports(fields=columns, **filters)
 
         headers, attrs = utils.calculate_header_and_attrs(
             column_headers, columns, parsed_args)
@@ -904,6 +956,11 @@ class UnsetPort(command.Command):
             action='store_true',
             help=_("Clear existing information of data plane status")
         )
+        parser.add_argument(
+            '--numa-policy',
+            action='store_true',
+            help=_("Clear existing NUMA affinity policy")
+        )
 
         _tag.add_tag_option_to_parser_for_unset(parser, _('port'))
 
@@ -959,6 +1016,8 @@ class UnsetPort(command.Command):
             attrs['qos_policy_id'] = None
         if parsed_args.data_plane_status:
             attrs['data_plane_status'] = None
+        if parsed_args.numa_policy:
+            attrs['numa_affinity_policy'] = None
 
         if attrs:
             client.update_port(obj, **attrs)
