@@ -61,7 +61,6 @@ _formatters = {
     'allocation_pools': AllocationPoolsColumn,
     'dns_nameservers': format_columns.ListColumn,
     'host_routes': HostRoutesColumn,
-    'location': format_columns.DictColumn,
     'service_types': format_columns.ListColumn,
     'tags': format_columns.ListColumn,
 }
@@ -673,6 +672,11 @@ class UnsetSubnet(command.Command):
                    'subnet e.g.: start=192.168.199.2,end=192.168.199.254 '
                    '(repeat option to unset multiple allocation pools)')
         )
+        parser.add_argument(
+            '--gateway',
+            action='store_true',
+            help=_("Remove gateway IP from this subnet")
+        )
         parser.add_argument(
             '--dns-nameserver',
             metavar='<dns-nameserver>',
@@ -716,6 +720,8 @@ class UnsetSubnet(command.Command):
         obj = client.find_subnet(parsed_args.subnet, ignore_missing=False)
 
         attrs = {}
+        if parsed_args.gateway:
+            attrs['gateway_ip'] = None
         if parsed_args.dns_nameservers:
             attrs['dns_nameservers'] = copy.deepcopy(obj.dns_nameservers)
             _update_arguments(attrs['dns_nameservers'],
