@@ -14,10 +14,12 @@
 #
 
 import copy
+import random
 from unittest import mock
 import uuid
 
 from novaclient import api_versions
+from openstack.compute.v2 import flavor as _flavor
 
 from openstackclient.api import compute_v2
 from openstackclient.tests.unit import fakes
@@ -163,7 +165,6 @@ class FakeComputev2Client(object):
         self.extensions.resource_class = fakes.FakeResource(None, {})
 
         self.flavors = mock.Mock()
-        self.flavors.resource_class = fakes.FakeResource(None, {})
 
         self.flavor_access = mock.Mock()
         self.flavor_access.resource_class = fakes.FakeResource(None, {})
@@ -195,9 +196,15 @@ class FakeComputev2Client(object):
         self.server_groups = mock.Mock()
         self.server_groups.resource_class = fakes.FakeResource(None, {})
 
+        self.server_migrations = mock.Mock()
+        self.server_migrations.resource_class = fakes.FakeResource(None, {})
+
         self.instance_action = mock.Mock()
         self.instance_action.resource_class = fakes.FakeResource(None, {})
 
+        self.migrations = mock.Mock()
+        self.migrations.resource_class = fakes.FakeResource(None, {})
+
         self.auth_token = kwargs['token']
 
         self.management_url = kwargs['endpoint']
@@ -770,27 +777,13 @@ class FakeFlavor(object):
             'os-flavor-access:is_public': True,
             'description': 'description',
             'OS-FLV-EXT-DATA:ephemeral': 0,
-            'properties': {'property': 'value'},
+            'extra_specs': {'property': 'value'},
         }
 
         # Overwrite default attributes.
         flavor_info.update(attrs)
 
-        # Set default methods.
-        flavor_methods = {
-            'set_keys': None,
-            'unset_keys': None,
-            'get_keys': {'property': 'value'},
-        }
-
-        flavor = fakes.FakeResource(info=copy.deepcopy(flavor_info),
-                                    methods=flavor_methods,
-                                    loaded=True)
-
-        # Set attributes with special mappings in nova client.
-        flavor.disabled = flavor_info['OS-FLV-DISABLED:disabled']
-        flavor.is_public = flavor_info['os-flavor-access:is_public']
-        flavor.ephemeral = flavor_info['OS-FLV-EXT-DATA:ephemeral']
+        flavor = _flavor.Flavor(**flavor_info)
 
         return flavor
 
@@ -877,6 +870,7 @@ class FakeKeypair(object):
         # Set default attributes.
         keypair_info = {
             'name': 'keypair-name-' + uuid.uuid4().hex,
+            'type': 'ssh',
             'fingerprint': 'dummy',
             'public_key': 'dummy',
             'user_id': 'user'
@@ -1244,7 +1238,7 @@ class FakeServerGroup(object):
     """Fake one server group"""
 
     @staticmethod
-    def create_one_server_group(attrs=None):
+    def _create_one_server_group(attrs=None):
         """Create a fake server group
 
         :param Dictionary attrs:
@@ -1261,7 +1255,6 @@ class FakeServerGroup(object):
             'members': [],
             'metadata': {},
             'name': 'server-group-name-' + uuid.uuid4().hex,
-            'policies': [],
             'project_id': 'server-group-project-id-' + uuid.uuid4().hex,
             'user_id': 'server-group-user-id-' + uuid.uuid4().hex,
         }
@@ -1274,6 +1267,38 @@ class FakeServerGroup(object):
             loaded=True)
         return server_group
 
+    @staticmethod
+    def create_one_server_group(attrs=None):
+        """Create a fake server group
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :return:
+            A FakeResource object, with id and other attributes
+        """
+        if attrs is None:
+            attrs = {}
+        attrs.setdefault('policies', ['policy1', 'policy2'])
+        return FakeServerGroup._create_one_server_group(attrs)
+
+
+class FakeServerGroupV264(object):
+    """Fake one server group fo API >= 2.64"""
+
+    @staticmethod
+    def create_one_server_group(attrs=None):
+        """Create a fake server group
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :return:
+            A FakeResource object, with id and other attributes
+        """
+        if attrs is None:
+            attrs = {}
+        attrs.setdefault('policy', 'policy1')
+        return FakeServerGroup._create_one_server_group(attrs)
+
 
 class FakeUsage(object):
     """Fake one or more usage."""
@@ -1539,3 +1564,183 @@ class FakeRateLimit(object):
         self.remain = remain
         self.unit = unit
         self.next_available = next_available
+
+
+class FakeMigration(object):
+    """Fake one or more migrations."""
+
+    @staticmethod
+    def create_one_migration(attrs=None, methods=None):
+        """Create a fake migration.
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :param Dictionary methods:
+            A dictionary with all methods
+        :return:
+            A FakeResource object, with id, type, and so on
+        """
+        attrs = attrs or {}
+        methods = methods or {}
+
+        # Set default attributes.
+        migration_info = {
+            "dest_host": "10.0.2.15",
+            "status": "migrating",
+            "type": "migration",
+            "updated_at": "2017-01-31T08:03:25.000000",
+            "created_at": "2017-01-31T08:03:21.000000",
+            "dest_compute": "compute-" + uuid.uuid4().hex,
+            "id": random.randint(1, 999),
+            "source_node": "node-" + uuid.uuid4().hex,
+            "server": uuid.uuid4().hex,
+            "dest_node": "node-" + uuid.uuid4().hex,
+            "source_compute": "compute-" + uuid.uuid4().hex,
+            "uuid": uuid.uuid4().hex,
+            "old_instance_type_id": uuid.uuid4().hex,
+            "new_instance_type_id": uuid.uuid4().hex,
+            "project": uuid.uuid4().hex,
+            "user": uuid.uuid4().hex
+        }
+
+        # Overwrite default attributes.
+        migration_info.update(attrs)
+
+        migration = fakes.FakeResource(info=copy.deepcopy(migration_info),
+                                       methods=methods,
+                                       loaded=True)
+        return migration
+
+    @staticmethod
+    def create_migrations(attrs=None, methods=None, count=2):
+        """Create multiple fake migrations.
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :param Dictionary methods:
+            A dictionary with all methods
+        :param int count:
+            The number of migrations to fake
+        :return:
+            A list of FakeResource objects faking the migrations
+        """
+        migrations = []
+        for i in range(0, count):
+            migrations.append(
+                FakeMigration.create_one_migration(
+                    attrs, methods))
+
+        return migrations
+
+
+class FakeServerMigration(object):
+    """Fake one or more server migrations."""
+
+    @staticmethod
+    def create_one_server_migration(attrs=None, methods=None):
+        """Create a fake server migration.
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :param Dictionary methods:
+            A dictionary with all methods
+        :return:
+            A FakeResource object, with id, type, and so on
+        """
+        attrs = attrs or {}
+        methods = methods or {}
+
+        # Set default attributes.
+
+        migration_info = {
+            "created_at": "2016-01-29T13:42:02.000000",
+            "dest_compute": "compute2",
+            "dest_host": "1.2.3.4",
+            "dest_node": "node2",
+            "id": random.randint(1, 999),
+            "server_uuid": uuid.uuid4().hex,
+            "source_compute": "compute1",
+            "source_node": "node1",
+            "status": "running",
+            "memory_total_bytes": random.randint(1, 99999),
+            "memory_processed_bytes": random.randint(1, 99999),
+            "memory_remaining_bytes": random.randint(1, 99999),
+            "disk_total_bytes": random.randint(1, 99999),
+            "disk_processed_bytes": random.randint(1, 99999),
+            "disk_remaining_bytes": random.randint(1, 99999),
+            "updated_at": "2016-01-29T13:42:02.000000",
+            # added in 2.59
+            "uuid": uuid.uuid4().hex,
+            # added in 2.80
+            "user_id": uuid.uuid4().hex,
+            "project_id": uuid.uuid4().hex,
+        }
+
+        # Overwrite default attributes.
+        migration_info.update(attrs)
+
+        migration = fakes.FakeResource(
+            info=copy.deepcopy(migration_info),
+            methods=methods,
+            loaded=True)
+        return migration
+
+
+class FakeVolumeAttachment(object):
+    """Fake one or more volume attachments (BDMs)."""
+
+    @staticmethod
+    def create_one_volume_attachment(attrs=None, methods=None):
+        """Create a fake volume attachment.
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :param Dictionary methods:
+            A dictionary with all methods
+        :return:
+            A FakeResource object, with id, device, and so on
+        """
+        attrs = attrs or {}
+        methods = methods or {}
+
+        # Set default attributes.
+        volume_attachment_info = {
+            "id": uuid.uuid4().hex,
+            "device": "/dev/sdb",
+            "serverId": uuid.uuid4().hex,
+            "volumeId": uuid.uuid4().hex,
+            # introduced in API microversion 2.70
+            "tag": "foo",
+            # introduced in API microversion 2.79
+            "delete_on_termination": True,
+        }
+
+        # Overwrite default attributes.
+        volume_attachment_info.update(attrs)
+
+        volume_attachment = fakes.FakeResource(
+            info=copy.deepcopy(volume_attachment_info),
+            methods=methods,
+            loaded=True)
+        return volume_attachment
+
+    @staticmethod
+    def create_volume_attachments(attrs=None, methods=None, count=2):
+        """Create multiple fake volume attachments (BDMs).
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :param Dictionary methods:
+            A dictionary with all methods
+        :param int count:
+            The number of volume attachments to fake
+        :return:
+            A list of FakeResource objects faking the volume attachments.
+        """
+        volume_attachments = []
+        for i in range(0, count):
+            volume_attachments.append(
+                FakeVolumeAttachment.create_one_volume_attachment(
+                    attrs, methods))
+
+        return volume_attachments
