@@ -130,10 +130,11 @@ class TestServerImageCreate(TestServerImage):
         self.servers_mock.create_image.assert_called_with(
             servers[0].id,
             servers[0].name,
+            None,
         )
 
         self.assertEqual(self.image_columns(images[0]), columns)
-        self.assertItemEqual(self.image_data(images[0]), data)
+        self.assertItemsEqual(self.image_data(images[0]), data)
 
     def test_server_image_create_options(self):
         servers = self.setup_servers_mock(count=1)
@@ -141,11 +142,13 @@ class TestServerImageCreate(TestServerImage):
 
         arglist = [
             '--name', 'img-nam',
+            '--property', 'key=value',
             servers[0].id,
         ]
         verifylist = [
             ('name', 'img-nam'),
             ('server', servers[0].id),
+            ('properties', {'key': 'value'}),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -158,10 +161,11 @@ class TestServerImageCreate(TestServerImage):
         self.servers_mock.create_image.assert_called_with(
             servers[0].id,
             'img-nam',
+            {'key': 'value'},
         )
 
         self.assertEqual(self.image_columns(images[0]), columns)
-        self.assertItemEqual(self.image_data(images[0]), data)
+        self.assertItemsEqual(self.image_data(images[0]), data)
 
     @mock.patch.object(common_utils, 'wait_for_status', return_value=False)
     def test_server_create_image_wait_fail(self, mock_wait_for_status):
@@ -188,6 +192,7 @@ class TestServerImageCreate(TestServerImage):
         self.servers_mock.create_image.assert_called_with(
             servers[0].id,
             servers[0].name,
+            None,
         )
 
         mock_wait_for_status.assert_called_once_with(
@@ -220,6 +225,7 @@ class TestServerImageCreate(TestServerImage):
         self.servers_mock.create_image.assert_called_with(
             servers[0].id,
             servers[0].name,
+            None,
         )
 
         mock_wait_for_status.assert_called_once_with(
@@ -229,4 +235,4 @@ class TestServerImageCreate(TestServerImage):
         )
 
         self.assertEqual(self.image_columns(images[0]), columns)
-        self.assertItemEqual(self.image_data(images[0]), data)
+        self.assertItemsEqual(self.image_data(images[0]), data)
