@@ -89,7 +89,7 @@ class TestIdentityProviderCreate(TestIdentityProvider):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertItemsEqual(self.datalist, data)
 
     def test_create_identity_provider_description(self):
         arglist = [
@@ -117,7 +117,7 @@ class TestIdentityProviderCreate(TestIdentityProvider):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertItemsEqual(self.datalist, data)
 
     def test_create_identity_provider_remote_id(self):
         arglist = [
@@ -145,7 +145,7 @@ class TestIdentityProviderCreate(TestIdentityProvider):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertItemsEqual(self.datalist, data)
 
     def test_create_identity_provider_remote_ids_multiple(self):
         arglist = [
@@ -174,7 +174,7 @@ class TestIdentityProviderCreate(TestIdentityProvider):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertItemsEqual(self.datalist, data)
 
     def test_create_identity_provider_remote_ids_file(self):
         arglist = [
@@ -207,7 +207,7 @@ class TestIdentityProviderCreate(TestIdentityProvider):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertItemsEqual(self.datalist, data)
 
     def test_create_identity_provider_disabled(self):
 
@@ -250,7 +250,7 @@ class TestIdentityProviderCreate(TestIdentityProvider):
             identity_fakes.idp_id,
             identity_fakes.formatted_idp_remote_ids
         )
-        self.assertItemEqual(datalist, data)
+        self.assertItemsEqual(datalist, data)
 
     def test_create_identity_provider_domain_name(self):
         arglist = [
@@ -278,7 +278,7 @@ class TestIdentityProviderCreate(TestIdentityProvider):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertItemsEqual(self.datalist, data)
 
     def test_create_identity_provider_domain_id(self):
         arglist = [
@@ -306,7 +306,7 @@ class TestIdentityProviderCreate(TestIdentityProvider):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertItemsEqual(self.datalist, data)
 
 
 class TestIdentityProviderDelete(TestIdentityProvider):
@@ -382,7 +382,62 @@ class TestIdentityProviderList(TestIdentityProvider):
             identity_fakes.domain_id,
             identity_fakes.idp_description,
         ), )
-        self.assertListItemEqual(datalist, tuple(data))
+        self.assertItemsEqual(datalist, tuple(data))
+
+    def test_identity_provider_list_ID_option(self):
+        arglist = ['--id',
+                   identity_fakes.idp_id]
+        verifylist = [
+            ('id', identity_fakes.idp_id)
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        # In base command class Lister in cliff, abstract method take_action()
+        # returns a tuple containing the column names and an iterable
+        # containing the data to be listed.
+        columns, data = self.cmd.take_action(parsed_args)
+
+        kwargs = {
+            'id': identity_fakes.idp_id
+        }
+        self.identity_providers_mock.list.assert_called_with(**kwargs)
+
+        collist = ('ID', 'Enabled', 'Domain ID', 'Description')
+        self.assertEqual(collist, columns)
+        datalist = ((
+            identity_fakes.idp_id,
+            True,
+            identity_fakes.domain_id,
+            identity_fakes.idp_description,
+        ), )
+        self.assertItemsEqual(datalist, tuple(data))
+
+    def test_identity_provider_list_enabled_option(self):
+        arglist = ['--enabled']
+        verifylist = [
+            ('enabled', True)
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        # In base command class Lister in cliff, abstract method take_action()
+        # returns a tuple containing the column names and an iterable
+        # containing the data to be listed.
+        columns, data = self.cmd.take_action(parsed_args)
+
+        kwargs = {
+            'enabled': True
+        }
+        self.identity_providers_mock.list.assert_called_with(**kwargs)
+
+        collist = ('ID', 'Enabled', 'Domain ID', 'Description')
+        self.assertEqual(collist, columns)
+        datalist = ((
+            identity_fakes.idp_id,
+            True,
+            identity_fakes.domain_id,
+            identity_fakes.idp_description,
+        ), )
+        self.assertItemsEqual(datalist, tuple(data))
 
 
 class TestIdentityProviderSet(TestIdentityProvider):
@@ -667,4 +722,4 @@ class TestIdentityProviderShow(TestIdentityProvider):
             identity_fakes.idp_id,
             identity_fakes.formatted_idp_remote_ids
         )
-        self.assertItemEqual(datalist, data)
+        self.assertItemsEqual(datalist, data)
