@@ -14,9 +14,10 @@
 #
 
 import argparse
-import mock
-from mock import call
+from unittest import mock
+from unittest.mock import call
 
+from osc_lib.cli import format_columns
 from osc_lib import exceptions
 from osc_lib import utils
 
@@ -68,8 +69,8 @@ class TestVolumeCreate(TestVolume):
         'bootable',
         'created_at',
         'display_description',
-        'display_name',
         'id',
+        'name',
         'properties',
         'size',
         'snapshot_id',
@@ -86,9 +87,9 @@ class TestVolumeCreate(TestVolume):
             self.new_volume.bootable,
             self.new_volume.created_at,
             self.new_volume.display_description,
-            self.new_volume.display_name,
             self.new_volume.id,
-            utils.format_dict(self.new_volume.metadata),
+            self.new_volume.display_name,
+            format_columns.DictColumn(self.new_volume.metadata),
             self.new_volume.size,
             self.new_volume.snapshot_id,
             self.new_volume.status,
@@ -134,7 +135,7 @@ class TestVolumeCreate(TestVolume):
             None,
         )
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.datalist, data)
+        self.assertItemsEqual(self.datalist, data)
 
     def test_volume_create_options(self):
         arglist = [
@@ -178,7 +179,7 @@ class TestVolumeCreate(TestVolume):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.datalist, data)
+        self.assertItemsEqual(self.datalist, data)
 
     def test_volume_create_user_project_id(self):
         # Return a project
@@ -225,7 +226,7 @@ class TestVolumeCreate(TestVolume):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.datalist, data)
+        self.assertItemsEqual(self.datalist, data)
 
     def test_volume_create_user_project_name(self):
         # Return a project
@@ -272,7 +273,7 @@ class TestVolumeCreate(TestVolume):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.datalist, data)
+        self.assertItemsEqual(self.datalist, data)
 
     def test_volume_create_properties(self):
         arglist = [
@@ -313,7 +314,7 @@ class TestVolumeCreate(TestVolume):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.datalist, data)
+        self.assertItemsEqual(self.datalist, data)
 
     def test_volume_create_image_id(self):
         image = image_fakes.FakeImage.create_one_image()
@@ -356,7 +357,7 @@ class TestVolumeCreate(TestVolume):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.datalist, data)
+        self.assertItemsEqual(self.datalist, data)
 
     def test_volume_create_image_name(self):
         image = image_fakes.FakeImage.create_one_image()
@@ -399,7 +400,7 @@ class TestVolumeCreate(TestVolume):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.datalist, data)
+        self.assertItemsEqual(self.datalist, data)
 
     def test_volume_create_with_source(self):
         self.volumes_mock.get.return_value = self.new_volume
@@ -429,7 +430,7 @@ class TestVolumeCreate(TestVolume):
             None,
         )
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.datalist, data)
+        self.assertItemsEqual(self.datalist, data)
 
     def test_volume_create_with_bootable_and_readonly(self):
         arglist = [
@@ -467,7 +468,7 @@ class TestVolumeCreate(TestVolume):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.datalist, data)
+        self.assertItemsEqual(self.datalist, data)
         self.volumes_mock.set_bootable.assert_called_with(
             self.new_volume.id, True)
         self.volumes_mock.update_readonly_flag.assert_called_with(
@@ -509,7 +510,7 @@ class TestVolumeCreate(TestVolume):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.datalist, data)
+        self.assertItemsEqual(self.datalist, data)
         self.volumes_mock.set_bootable.assert_called_with(
             self.new_volume.id, False)
         self.volumes_mock.update_readonly_flag.assert_called_with(
@@ -561,7 +562,7 @@ class TestVolumeCreate(TestVolume):
 
         self.assertEqual(2, mock_error.call_count)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.datalist, data)
+        self.assertItemsEqual(self.datalist, data)
         self.volumes_mock.set_bootable.assert_called_with(
             self.new_volume.id, True)
         self.volumes_mock.update_readonly_flag.assert_called_with(
@@ -598,6 +599,38 @@ class TestVolumeCreate(TestVolume):
         self.assertRaises(tests_utils.ParserException, self.check_parser,
                           self.cmd, arglist, verifylist)
 
+    def test_volume_create_backward_compatibility(self):
+        arglist = [
+            '-c', 'display_name',
+            '--size', str(self.new_volume.size),
+            self.new_volume.display_name,
+        ]
+        verifylist = [
+            ('columns', ['display_name']),
+            ('size', self.new_volume.size),
+            ('name', self.new_volume.display_name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.volumes_mock.create.assert_called_with(
+            self.new_volume.size,
+            None,
+            None,
+            self.new_volume.display_name,
+            None,
+            None,
+            None,
+            None,
+            None,
+            None,
+            None,
+        )
+        self.assertIn('display_name', columns)
+        self.assertNotIn('name', columns)
+        self.assertIn(self.new_volume.display_name, data)
+
 
 class TestVolumeDelete(TestVolume):
 
@@ -695,21 +728,18 @@ class TestVolumeList(TestVolume):
     _volume = volume_fakes.FakeVolume.create_one_volume()
     columns = (
         'ID',
-        'Display Name',
+        'Name',
         'Status',
         'Size',
         'Attached to',
     )
-    server = _volume.attachments[0]['server_id']
-    device = _volume.attachments[0]['device']
-    msg = 'Attached to %s on %s ' % (server, device)
     datalist = (
         (
             _volume.id,
             _volume.display_name,
             _volume.status,
             _volume.size,
-            msg,
+            volume.AttachmentsColumn(_volume.attachments),
         ),
     )
 
@@ -735,7 +765,7 @@ class TestVolumeList(TestVolume):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.datalist, tuple(data))
+        self.assertItemsEqual(self.datalist, tuple(data))
 
     def test_volume_list_name(self):
         arglist = [
@@ -752,7 +782,7 @@ class TestVolumeList(TestVolume):
 
         columns, data = self.cmd.take_action(parsed_args)
         self.assertEqual(self.columns, tuple(columns))
-        self.assertEqual(self.datalist, tuple(data))
+        self.assertItemsEqual(self.datalist, tuple(data))
 
     def test_volume_list_status(self):
         arglist = [
@@ -769,7 +799,7 @@ class TestVolumeList(TestVolume):
 
         columns, data = self.cmd.take_action(parsed_args)
         self.assertEqual(self.columns, tuple(columns))
-        self.assertEqual(self.datalist, tuple(data))
+        self.assertItemsEqual(self.datalist, tuple(data))
 
     def test_volume_list_all_projects(self):
         arglist = [
@@ -786,7 +816,7 @@ class TestVolumeList(TestVolume):
 
         columns, data = self.cmd.take_action(parsed_args)
         self.assertEqual(self.columns, tuple(columns))
-        self.assertEqual(self.datalist, tuple(data))
+        self.assertItemsEqual(self.datalist, tuple(data))
 
     def test_volume_list_long(self):
         arglist = [
@@ -806,7 +836,7 @@ class TestVolumeList(TestVolume):
 
         collist = (
             'ID',
-            'Display Name',
+            'Name',
             'Status',
             'Size',
             'Type',
@@ -823,10 +853,10 @@ class TestVolumeList(TestVolume):
             self._volume.size,
             self._volume.volume_type,
             self._volume.bootable,
-            self.msg,
-            utils.format_dict(self._volume.metadata),
+            volume.AttachmentsColumn(self._volume.attachments),
+            format_columns.DictColumn(self._volume.metadata),
         ), )
-        self.assertEqual(datalist, tuple(data))
+        self.assertItemsEqual(datalist, tuple(data))
 
     def test_volume_list_with_limit(self):
         arglist = [
@@ -851,7 +881,7 @@ class TestVolumeList(TestVolume):
                 'all_tenants': False, }
         )
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.datalist, tuple(data))
+        self.assertItemsEqual(self.datalist, tuple(data))
 
     def test_volume_list_negative_limit(self):
         arglist = [
@@ -863,6 +893,27 @@ class TestVolumeList(TestVolume):
         self.assertRaises(argparse.ArgumentTypeError, self.check_parser,
                           self.cmd, arglist, verifylist)
 
+    def test_volume_list_backward_compatibility(self):
+        arglist = [
+            '-c', 'Display Name',
+        ]
+        verifylist = [
+            ('columns', ['Display Name']),
+            ('long', False),
+            ('all_projects', False),
+            ('name', None),
+            ('status', None),
+            ('limit', None),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.assertIn('Display Name', columns)
+        self.assertNotIn('Name', columns)
+        for each_volume in data:
+            self.assertIn(self._volume.display_name, each_volume)
+
 
 class TestVolumeMigrate(TestVolume):
 
@@ -1071,6 +1122,7 @@ class TestVolumeSet(TestVolume):
 
     def test_volume_set_property(self):
         arglist = [
+            '--no-property',
             '--property', 'myprop=myvalue',
             self._volume.display_name,
         ]
@@ -1080,6 +1132,7 @@ class TestVolumeSet(TestVolume):
             ('name', None),
             ('description', None),
             ('size', None),
+            ('no_property', True),
             ('property', {'myprop': 'myvalue'}),
             ('volume', self._volume.display_name),
             ('bootable', False),
@@ -1097,6 +1150,10 @@ class TestVolumeSet(TestVolume):
             self._volume.id,
             metadata
         )
+        self.volumes_mock.delete_metadata.assert_called_with(
+            self._volume.id,
+            self._volume.metadata.keys()
+        )
         self.volumes_mock.update_readonly_flag.assert_not_called()
         self.assertIsNone(result)
 
@@ -1172,8 +1229,8 @@ class TestVolumeShow(TestVolume):
         'bootable',
         'created_at',
         'display_description',
-        'display_name',
         'id',
+        'name',
         'properties',
         'size',
         'snapshot_id',
@@ -1190,9 +1247,9 @@ class TestVolumeShow(TestVolume):
             self._volume.bootable,
             self._volume.created_at,
             self._volume.display_description,
-            self._volume.display_name,
             self._volume.id,
-            utils.format_dict(self._volume.metadata),
+            self._volume.display_name,
+            format_columns.DictColumn(self._volume.metadata),
             self._volume.size,
             self._volume.snapshot_id,
             self._volume.status,
@@ -1215,7 +1272,26 @@ class TestVolumeShow(TestVolume):
         self.volumes_mock.get.assert_called_with(self._volume.id)
 
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.datalist, data)
+        self.assertItemsEqual(self.datalist, data)
+
+    def test_volume_show_backward_compatibility(self):
+        arglist = [
+            '-c', 'display_name',
+            self._volume.id,
+        ]
+        verifylist = [
+            ('columns', ['display_name']),
+            ('volume', self._volume.id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.volumes_mock.get.assert_called_with(self._volume.id)
+
+        self.assertIn('display_name', columns)
+        self.assertNotIn('name', columns)
+        self.assertIn(self._volume.display_name, data)
 
 
 class TestVolumeUnset(TestVolume):
@@ -1261,3 +1337,31 @@ class TestVolumeUnset(TestVolume):
             self._volume.id, ['myprop']
         )
         self.assertIsNone(result)
+
+
+class TestColumns(TestVolume):
+
+    def test_attachments_column_without_server_cache(self):
+        _volume = volume_fakes.FakeVolume.create_one_volume()
+        server_id = _volume.attachments[0]['server_id']
+        device = _volume.attachments[0]['device']
+
+        col = volume.AttachmentsColumn(_volume.attachments, {})
+        self.assertEqual('Attached to %s on %s ' % (server_id, device),
+                         col.human_readable())
+        self.assertEqual(_volume.attachments, col.machine_readable())
+
+    def test_attachments_column_with_server_cache(self):
+        _volume = volume_fakes.FakeVolume.create_one_volume()
+
+        server_id = _volume.attachments[0]['server_id']
+        device = _volume.attachments[0]['device']
+        fake_server = mock.Mock()
+        fake_server.name = 'fake-server-name'
+        server_cache = {server_id: fake_server}
+
+        col = volume.AttachmentsColumn(_volume.attachments, server_cache)
+        self.assertEqual(
+            'Attached to %s on %s ' % ('fake-server-name', device),
+            col.human_readable())
+        self.assertEqual(_volume.attachments, col.machine_readable())
